@@ -274,7 +274,8 @@ static char *const *original_argv;
    to getopt is that one passed to the process.  */
 static void store_args(
     int argc,
-    char *const *argv) __attribute__ ((unused));
+    char *const *argv);
+
 static void store_args(
     int argc,
     char *const *argv)
@@ -359,7 +360,7 @@ static const char *_getopt_initialize(
     const char *);
 #endif
 static const char* _getopt_initialize(int argc,
-                                      char** argv,
+                                      char* const* argv,
                                       const char* optstring)
 {
     /* Start processing options with ARGV-element 1 (since ARGV-element 0
@@ -464,7 +465,7 @@ static const char* _getopt_initialize(int argc,
    long-named options.  */
 
 int _getopt_internal(int argc,
-                     char** argv,
+                     char* const* argv,
                      const char *optstring,
                      const struct option *longopts,
                      int* longind,
@@ -868,15 +869,6 @@ int _getopt_internal(int argc,
     }
 }
 
-int getopt(
-    int argc,
-    char** argv,
-    const char* optstring)
-{
-    return _getopt_internal(argc, argv, optstring,
-                            (const struct option *) 0, (int *) 0, 0);
-}
-
 #endif                          /* Not ELIDE_CODE.  */
 
 #ifdef TEST
